# Python Lemmy API Wrapper
Like PRAW but for Lemmy

Written using the [Lemmy TS library](https://github.com/LemmyNet/lemmy-js-client) for reference.

Forked from benja810's plaw

Currently, most of the API functions are implemented, but there are likely quite a few bugs. It is a bit difficult to test at the moment without spinning up a new instance. 

If you find any bugs, let me know on the [issues page](https://github.com/amarpersaud/python-jplaw/issues)